VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
END
Attribute VB_Name = "clsGeneral"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = True
Attribute VB_PredeclaredId = False
Attribute VB_Exposed = True
' ------------------------------------------------------
' General.CLS
' Copyright (c) Slightly Tilted Software 1999
' By: L.J. Johnson       Date: 04-26-1999
' Comments: Used to populate the initial form of the
'           Server applet
' ------------------------------------------------------
Option Explicit
Option Base 1
Option Compare Text
DefLng A-Z

' --------------------------------------------
' Must deal with the local computer name
' --------------------------------------------
Private Const constLocal_Computer      As String = "**LOCAL**"

' --------------------------------------------
' Used to get the NT computers on the network
' --------------------------------------------
' Constants for type of computer
Private Enum enumServerType
   SV_TYPE_WORKSTATION = &H1&
   SV_TYPE_SERVER = &H2&
   SV_TYPE_SQLSERVER = &H4&
   SV_TYPE_DOMAIN_CTRL = &H8&
   SV_TYPE_DOMAIN_BAKCTRL = &H10&
   SV_TYPE_NOVELL = &H80&
   SV_TYPE_NT = &H1000&
   SV_TYPE_WFW = &H2000&
   SV_TYPE_SERVER_NT = &H8000&
   SV_TYPE_WINDOWS = &H400000
   SV_TYPE_ALL = &HFFFF
End Enum

' Type used by NetServerEnum
Private Type SERVER_INFO_101
    sv101_platform_id As Long
    sv101_servername As Long
    sv101_ver_major As Long
    sv101_ver_minor As Long
    s101_servertype As Long
    s101_comment As Long
End Type

Private Declare Function NetServerEnum Lib "Netapi32" _
      (ByVal sServerName As String, _
       ByVal lLevel As Long, _
       vBuffer As Long, _
       lPreferedMaxLen As Long, _
       lEntriesRead As Long, _
       lTotalEntries As Long, _
       ByVal vServerType As Long, _
       ByVal sDomain As String, _
       vResume As Long) As Long

' --------------------------------------------
' Private variable(s) to hold data for public
'     properties
' --------------------------------------------
Private m_lngNumSessions               As Long
Private m_lngNumFileLocks              As Long
Private m_lngNumOpenFiles              As Long
Private m_lngNumOpenPipes              As Long
Private m_strComputerDesc              As String
Private m_strLocalComputer             As String
Private m_astrComputerNames()          As String

' *******************************************************
' Routine Name : (PUBLIC in CLASS) Property Get NumSessions
' Written By   : L.J. Johnson
' Programmer   : L.J. Johnson [Slightly Tilted Software]
' Date Writen  : 04/26/1999 -- 11:44:52
' Inputs       : N/A
' Outputs      : Long -- Number of session
' Description  : Read-only property for the number of Sessions
' *******************************************************
Public Property Get NumSessions() As Long
   NumSessions = m_lngNumSessions
End Property

' *******************************************************
' Routine Name : (PUBLIC in CLASS) Property Get NumFileLocks
' Written By   : L.J. Johnson
' Programmer   : L.J. Johnson [Slightly Tilted Software]
' Date Writen  : 04/26/1999 -- 11:44:49
' Inputs       : N/A
' Outputs      : Long -- Number of file locks
' Description  : Read-only property for the number of Locks
' *******************************************************
Public Property Get NumFileLocks() As Long
   NumFileLocks = m_lngNumFileLocks
End Property

' *******************************************************
' Routine Name : (PUBLIC in CLASS) Property Get NumOpenFiles
' Written By   : L.J. Johnson
' Programmer   : L.J. Johnson [Slightly Tilted Software]
' Date Writen  : 04/26/1999 -- 11:44:46
' Inputs       : N/A
' Outputs      : Long -- Number of open files
' Description  : Read-only property for the number of Open Files
' *******************************************************
Public Property Get NumOpenFiles() As Long
   NumOpenFiles = m_lngNumOpenFiles
End Property

' *******************************************************
' Routine Name : (PUBLIC in CLASS) Property Get NumOpenPipes
' Written By   : L.J. Johnson
' Programmer   : L.J. Johnson [Slightly Tilted Software]
' Date Writen  : 04/26/1999 -- 11:44:44
' Inputs       : N/A
' Outputs      : Long -- Number of open pipes
' Description  : Read-only property for the number of Open Pipes
' *******************************************************
Public Property Get NumOpenPipes() As Long
   NumOpenPipes = m_lngNumOpenPipes
End Property

' *******************************************************
' Routine Name : (PUBLIC in CLASS) Property Get ComputerDesc
' Written By   : L.J. Johnson
' Programmer   : L.J. Johnson [Slightly Tilted Software]
' Date Writen  : 04/26/1999 -- 11:46:42
' Inputs       : N/A
' Outputs      : String -- Computer description
' Description  : Read/Write property for the computer
'              :     description (i.e., comment)
' *******************************************************
Public Property Get ComputerDesc() As String
   ComputerDesc = m_strComputerDesc
End Property

' *******************************************************
' Routine Name : (PUBLIC in CLASS) Property Let ComputerDesc
' Written By   : L.J. Johnson
' Programmer   : L.J. Johnson [Slightly Tilted Software]
' Date Writen  : 04/26/1999 -- 11:47:41
' Inputs       : ByVal xi_strComputerDesc:String - The new computer description
' Outputs      : N/A
' Description  : Read/Write property for the computer
'              :     description (i.e., comment)
' *******************************************************
Public Property Let ComputerDesc(ByVal ComputerDescription As String)
   Dim p_abytServerName()              As Byte
   Dim p_lngRtn                        As Long
   Dim p_lngParmError                  As Long
   Dim p_lngPtrDescription             As Long
   Dim p_typComputerInfo               As Server_Info_1005
   
   ' ------------------------------------------
   ' Initialize the variable(s)
   ' ------------------------------------------
   p_abytServerName = Chr$(0)
   p_lngPtrDescription = StrPtr(ComputerDesc) & Chr(0)
   
   ' ------------------------------------------
   ' Make appropriate API call and check for error
   ' ------------------------------------------
   p_lngRtn = NetServerSetInfo(ServerName:=p_abytServerName(0), _
                               Level:=1005, _
                               Buffer:=p_lngPtrDescription, _
                               ParmError:=p_lngParmError)
   If p_lngRtn <> 0 Then
      MsgBox "Had an error with NetServerSetInfo, " & CStr(p_lngRtn) & _
             " -- " & ReturnApiErrString(p_lngRtn), _
             Buttons:=vbInformation, _
             Title:=g_constMsgTitle
      Exit Property
   End If
    
   ' ------------------------------------------
   ' Clean-up the buffer
   ' ------------------------------------------
   If p_lngPtrDescription <> 0 Then
      NetApiBufferFree p_lngPtrDescription
   End If
   
   ' ------------------------------------------
   ' Set the computer description at module level
   ' ------------------------------------------
   m_strComputerDesc = ComputerDescription

End Property

' *******************************************************
' Routine Name : (PUBLIC in CLASS) Sub Init
' Written By   : L.J. Johnson
' Programmer   : L.J. Johnson [Slightly Tilted Software]
' Date Writen  : 04/26/1999 -- 11:43:40
' Inputs       : N/A
' Outputs      : N/A
' Description  : Called from the Class_Initialize function
'              :     to fill in the public properties
' *******************************************************
Public Sub Init(Optional ByVal ServerName As String = "")
   Dim p_strComputerDesc               As String
   Dim p_abytServerName()              As Byte
   Dim p_abytUncClientName()           As Byte
   Dim p_abytUserName()                As Byte
   Dim p_abytBasePath()                As Byte
   Dim p_abytQualifier()               As Byte
   Dim p_lngRtn                        As Long
   Dim p_lngPtrBuffer                  As Long
   Dim p_lngEntriesRead                As Long
   Dim p_lngTotalEntries               As Long
   Dim p_lngResumeHwnd                 As Long
   Dim p_lngLoop                       As Long
   Dim p_lngNumLocks                   As Long
   Dim p_lngNumOpenPipes               As Long
   Dim p_lngLenName                    As Long
   Dim p_strPathName                   As String
   Dim p_typComputerInfo               As SERVER_INFO_101
   Dim p_atypSessionInfo()             As Session_Info_502
   Dim p_atypFileInfo()                As File_Info_3
   Dim p_atypConnInfo()                As Connection_Info_1
   
   ' ******************************************
   ' Get # Sessions
   ' ******************************************
   p_abytServerName = ServerName & Chr$(0)
   p_abytUncClientName = Chr$(0)
   p_abytUserName = Chr$(0)
   
   m_lngNumSessions = 0&
   
   ' ------------------------------------------
   ' Make appropriate API call and check for error
   ' ------------------------------------------
   p_lngRtn = NetSessionEnum(ServerName:=p_abytServerName(0), _
                             UncClientName:=p_abytUncClientName(0), _
                             UserName:=p_abytUserName(0), _
                             Level:=502, _
                             Buffer:=p_lngPtrBuffer, _
                             PreMaxLen:=4096, _
                             EntriesRead:=p_lngEntriesRead, _
                             TotalEntries:=p_lngTotalEntries, _
                             Resume_Handle:=p_lngResumeHwnd)
   If p_lngRtn <> 0 Then
      MsgBox "Had an error with NetSessionEnum, " & CStr(p_lngRtn) & _
             " -- " & ReturnApiErrString(p_lngRtn), _
             Buttons:=vbInformation, _
             Title:=g_constMsgTitle
   End If

   ' ------------------------------------------
   ' Clean-up the buffer
   ' ------------------------------------------
   If p_lngPtrBuffer <> 0 Then
      NetApiBufferFree p_lngPtrBuffer
   End If
   
   ' ------------------------------------------
   ' Set the # of sessions
   ' ------------------------------------------
   m_lngNumSessions = p_lngTotalEntries
   
   ' ******************************************
   ' Get # File locks & # Open files
   ' ******************************************
   p_abytServerName = ServerName & Chr$(0)
   p_abytUserName = Chr$(0)
   p_abytBasePath = Chr$(0)
   p_lngNumOpenPipes = 0
   
   ' ------------------------------------------
   ' Make the API call
   ' ------------------------------------------
   p_lngRtn = NetFileEnum(ServerName:=p_abytServerName(0), _
                          BasePath:=p_abytBasePath(0), _
                          UserName:=p_abytUserName(0), _
                          Level:=3, _
                          BufPtr:=p_lngPtrBuffer, _
                          PrefMaxLen:=4096, _
                          EntriesRead:=p_lngEntriesRead, _
                          TotalLenEntries:=p_lngTotalEntries, _
                          ResumeHwnd:=p_lngResumeHwnd)
   If p_lngRtn <> 0 Then
      MsgBox "Had an error with NetFileEnum, " & CStr(p_lngRtn) & _
             " -- " & ReturnApiErrString(p_lngRtn), _
             Buttons:=vbInformation, _
             Title:=g_constMsgTitle
   End If
   
   p_lngNumLocks = 0&
   
   If p_lngEntriesRead > 0 Then
      ReDim p_atypFileInfo(0 To p_lngEntriesRead - 1)
         
      ' ---------------------------------------
      ' Copy the pointer to the buffer into the
      '     type array
      ' ---------------------------------------
      CopyMem p_atypFileInfo(0), _
              ByVal p_lngPtrBuffer, _
              Len(p_atypFileInfo(0)) * p_lngEntriesRead

      For p_lngLoop = 0 To p_lngEntriesRead - 1
         p_lngNumLocks = p_lngNumLocks + p_atypFileInfo(p_lngLoop).fi3_num_locks
         p_strPathName = UCase$(PointerToUnicodeStr(p_atypFileInfo(p_lngLoop).fi3_pathname))
         If Left$(p_strPathName, 6) = "\PIPE\" Then
            p_lngNumOpenPipes = p_lngNumOpenPipes + 1
         End If
      Next p_lngLoop
   End If

   ' ------------------------------------------
   ' Set the # of open pipes
   ' NOTE: We will always have +1 open pipe,
   '       since in making this call we create
   '       a pipe, "\PIPE\srvsvc"
   ' ------------------------------------------
   m_lngNumOpenPipes = p_lngNumOpenPipes
   
   ' ------------------------------------------
   ' Clean-up the buffer
   ' ------------------------------------------
   If p_lngPtrBuffer <> 0 Then
      NetApiBufferFree p_lngPtrBuffer
   End If
   
   ' ------------------------------------------
   ' Set the # file locks and # of open file
   ' ------------------------------------------
   m_lngNumFileLocks = p_lngNumLocks
   m_lngNumOpenFiles = p_lngEntriesRead
   
   ' ******************************************
   ' Get the description for the computer
   ' ******************************************
   p_abytServerName = ServerName & Chr$(0)
   
   ' ------------------------------------------
   ' Make the API call
   ' ------------------------------------------
   p_lngRtn = NetServerGetInfo(ServerName:=p_abytServerName(0), _
                               Level:=101, _
                               Buffer:=p_lngPtrBuffer)
   If p_lngRtn <> 0 Then
      MsgBox "Had an error with NetServerGetInfo, " & CStr(p_lngRtn) & _
             " -- " & ReturnApiErrString(p_lngRtn), _
             Buttons:=vbInformation, _
             Title:=g_constMsgTitle
   End If
   
   ' ------------------------------------------
   ' Copy the pointer to the buffer into the
   '     type array
   ' ------------------------------------------
   CopyMem p_typComputerInfo, _
           ByVal p_lngPtrBuffer, _
           Len(p_typComputerInfo)
   p_strComputerDesc = PointerToUnicodeStr(p_typComputerInfo.s101_comment)
   
   ' ------------------------------------------
   ' Clean-up the buffer
   ' ------------------------------------------
   If p_lngPtrBuffer <> 0 Then
      NetApiBufferFree p_lngPtrBuffer
   End If
   
   ' ------------------------------------------
   ' Set the computer description
   ' ------------------------------------------
   m_strComputerDesc = p_strComputerDesc
   
   ' ******************************************
   ' Get the name for this computer
   ' ******************************************
   m_strLocalComputer = String$(255, Chr$(0))
   p_lngLenName = Len(m_strLocalComputer) + 1
   p_lngRtn = GetComputerName(lpBuffer:=m_strLocalComputer, _
                              nSize:=p_lngLenName)
   If p_lngRtn <> 0 Then
      m_strLocalComputer = Mid$(m_strLocalComputer, 1, p_lngLenName)
   Else
      p_lngRtn = Err.LastDllError
      MsgBox "Had an error with GetComputerName, " & CStr(p_lngRtn) & _
             " -- " & ReturnApiErrString(p_lngRtn), _
             Buttons:=vbInformation, _
             Title:=g_constMsgTitle
   End If
   
   ' ******************************************
   ' Get # of Open Named Pipes
   ' ******************************************
'   p_abytServerName = ServerName & Chr$(0)
'   p_abytQualifier = "\\" & m_strLocalComputer & Chr$(0)
'
'   p_lngRtn = NetConnectionEnum(ServerName:=p_abytServerName(0), _
'                                Qualifier:=p_abytQualifier(0), _
'                                Level:=1, _
'                                Buffer:=p_lngPtrBuffer, _
'                                PreMaxLen:=4096&, _
'                                EntriesRead:=p_lngEntriesRead, _
'                                TotalEntries:=p_lngTotalEntries, _
'                                Resume_Handle:=p_lngResumeHwnd)
'   If p_lngRtn <> NERR_Success Then
'      MsgBox "Had an error with NetConnectionEnum, " & CStr(p_lngRtn) & _
'             " -- " & ReturnApiErrString(p_lngRtn), _
'             Buttons:=vbInformation, _
'             Title:=g_constMsgTitle
'   End If
'
'   p_lngNumOpenPipes = 0
'   If p_lngEntriesRead > 0 Then
'      ReDim p_atypConnInfo(0 To p_lngEntriesRead - 1)
'
'      ' ---------------------------------------
'      ' Copy the pointer to the buffer into the
'      '     type array
'      ' ---------------------------------------
'      CopyMem p_atypConnInfo(0), _
'              ByVal p_lngPtrBuffer, _
'              Len(p_atypConnInfo(0)) * p_lngEntriesRead
'
'      For p_lngLoop = 0 To p_lngEntriesRead - 1
'         If p_atypConnInfo(p_lngLoop).coni1_type = STYPE_IPC Then
'            p_lngNumOpenPipes = p_lngNumOpenPipes + 1
'         End If
'      Next p_lngLoop
'   End If
'
'   ' ------------------------------------------
'   ' Clean-up the buffer
'   ' ------------------------------------------
'   If p_lngPtrBuffer <> 0 Then
'      NetApiBufferFree p_lngPtrBuffer
'   End If
'
'   ' ------------------------------------------
'   ' Set the # of open pipes
'   ' ------------------------------------------
'   m_lngNumOpenPipes = p_lngNumOpenPipes
'
End Sub

' *******************************************************
' Routine Name : (PUBLIC in CLASS) Sub GetComputersNames
' Written By   : L.J. Johnson
' Programmer   : L.J. Johnson [Slightly Tilted Software]
' Date Writen  : 05/02/1999 -- 22:57:12
' Inputs       : N/A
' Outputs      : N/A
' Description  : Get the names of all the NT computers on
'              :     the network: PDCs, BDCs, Servers,
'              :     and workstations. Set the module-leve
'              :     variable: m_astrComputerNames()
' Called By    : Me.Init
' *******************************************************
Public Function GetComputersNames() As Variant
   Dim p_strServerName                 As String
   Dim p_strComputerName               As String
   Dim p_strDomainName                 As String
   Dim p_abytBuf(0 To 4096)            As Byte
   Dim p_lngRtn                        As Long
   Dim p_lngPreferedMaxLen             As Long
   Dim p_lngNumEntriesRead             As Long
   Dim p_lngTotalEntries               As Long
   Dim p_lngResume                     As Long
   Dim p_lngCount                      As Long
   Dim p_lngPtrSvrInfoStruct           As Long
   Dim p_lngServEnumLevel              As Long
   Dim p_lngPos                        As Long
   Dim p_lngLenComputerName            As Long
   Dim p_lngServerFlags                As Long
   Dim p_atypServerInfo101             As SERVER_INFO_101
   
   ' ------------------------------------------
   ' Initialize the variables
   ' ------------------------------------------
   p_strComputerName = vbNullString
   p_strServerName = vbNullString
   p_strDomainName = vbNullString
   p_lngServEnumLevel = 101
   p_lngServerFlags = enumServerType.SV_TYPE_NT
   
   ' ------------------------------------------
   ' Call NetServerEnum to get a list of Servers
   ' ------------------------------------------
   p_lngRtn = NetServerEnum(p_strServerName, _
                            p_lngServEnumLevel, _
                            p_lngPtrSvrInfoStruct, _
                            p_lngPreferedMaxLen, _
                            p_lngNumEntriesRead, _
                            p_lngTotalEntries, _
                            p_lngServerFlags, _
                            p_strDomainName, _
                            p_lngResume)

   ' ------------------------------------------
   ' If successful, the return will = 0
   ' ------------------------------------------
   If p_lngRtn <> 0 Then
      ReDim m_astrComputerNames(1 To 1)
      m_astrComputerNames(1) = constLocal_Computer
      GetComputersNames = m_astrComputerNames
      Exit Function
   End If
   
   ' ------------------------------------------
   ' NetServerEnum Index is 1 based -- iterate
   '     thru the return values to get the
   '     NT servers and workstations
   ' ------------------------------------------
   p_lngCount = 1
   
   ' ------------------------------------------
   ' Exit if no entries
   ' ------------------------------------------
   If p_lngTotalEntries <= 0 Then
      ReDim m_astrComputerNames(1 To 1)
      m_astrComputerNames(1) = constLocal_Computer
      GetComputersNames = m_astrComputerNames
      Exit Function
   End If
   
   ' ------------------------------------------
   ' Redim the module-level array
   ' ------------------------------------------
   ReDim m_astrComputerNames(1 To p_lngTotalEntries)

   ' ------------------------------------------
   ' Iterate thru and fill in the names of the
   '     computers on the network
   ' ------------------------------------------
   For p_lngCount = 1 To p_lngTotalEntries
      p_strComputerName = ""

      CopyMem p_atypServerInfo101, _
              ByVal p_lngPtrSvrInfoStruct, _
              Len(p_atypServerInfo101)

      ' ---------------------------------------
      ' Get the server name
      ' ---------------------------------------
      StrCopyW p_abytBuf(0), _
               p_atypServerInfo101.sv101_servername
      On Error Resume Next
      p_strComputerName = p_abytBuf
      p_lngPos = InStr(p_strComputerName, vbNullChar)
      
      If p_lngPos > 0 Then
         p_strComputerName = Mid$(p_strComputerName, 1, p_lngPos - 1)
      End If
      
      ' ---------------------------------------
      ' Translate the local computer name into
      '     a string constant
      ' ---------------------------------------
      If UCase$(Trim$(m_strLocalComputer)) = UCase$(Trim$(p_strComputerName)) Then
         p_strComputerName = constLocal_Computer
      End If
      
      ' ---------------------------------------
      ' Place name into the string array
      ' ---------------------------------------
      m_astrComputerNames(p_lngCount) = p_strComputerName
      
      p_lngPtrSvrInfoStruct = p_lngPtrSvrInfoStruct + Len(p_atypServerInfo101)
   Next p_lngCount

   ' ------------------------------------------
   ' Clean up the buffer and set return value
   ' ------------------------------------------
   p_lngRtn = NetApiBufferFree(p_lngPtrSvrInfoStruct)
   GetComputersNames = m_astrComputerNames

End Function
