VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
END
Attribute VB_Name = "colConnectionEnum"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = True
Attribute VB_PredeclaredId = False
Attribute VB_Exposed = True
Attribute VB_Ext_KEY = "SavedWithClassBuilder" ,"Yes"
Attribute VB_Ext_KEY = "Top_Level" ,"No"
Attribute VB_Ext_KEY = "Collection" ,"clsConnectionEnum"
Attribute VB_Ext_KEY = "Member0" ,"clsConnectionEnum"
' ------------------------------------------------------
' colConnectionEnum.CLS
' Copyright (c) Slightly Tilted Software 1999
' By: L.J. Johnson       Date: 04-26-1999
' Comments: Collection class to manage collection of
'           Connection enumeration objects
' ------------------------------------------------------
Option Explicit
Option Base 1
Option Compare Text
DefLng A-Z

' --------------------------------------------
' Private variable to hold public property value
' --------------------------------------------
Private m_strQualifier                 As String
Private m_strServerName                As String

' --------------------------------------------
' Local variable to hold collection
' --------------------------------------------
Private m_colConnectEnum As Collection

' *******************************************************
' Routine Name : (PRIVATE in CLASS) Sub Add
' Written By   : L.J. Johnson
' Programmer   : L.J. Johnson [Slightly Tilted Software]
' Date Writen  : 04/26/1999 -- 12:23:29
' Inputs       : ByVal ConnectionType:enumShareType -
'              : ByVal ConnectionID:Long -
'              : ByVal NumOpens:Long -
'              : ByVal NumUsers:Long -
'              : ByVal ConnectionTime:Long -
'              : ByVal UserName:String -
'              : ByVal NetName:String -
' Outputs      : N/A
' Description  : Don't have a public Add() method -- the
'              :     API call in ConnectionEnum() which
'              :     is called by the Init() method will
'              :     populate the info via repeated calls
'              :     to the Add() method
' *******************************************************
Private Sub Add(ByVal ConnectionType As enumShareType, _
                ByVal ConnectionID As Long, _
                ByVal NumOpens As Long, _
                ByVal NumUsers As Long, _
                ByVal ConnectionTime As Long, _
                ByVal UserName As String, _
                ByVal NetName As String)
   Dim p_objConnectionEnum             As clsConnectionEnum
   
   Set p_objConnectionEnum = New clsConnectionEnum
   p_objConnectionEnum.Init xi_enmConnectionType:=ConnectionType, _
                            xi_lngConnectionID:=ConnectionID, _
                            xi_lngNumOpens:=NumOpens, _
                            xi_lngNumUsers:=NumUsers, _
                            xi_lngConnectionTime:=ConnectionTime, _
                            xi_strConnectTimeFormatted:=ConvertSeconds(ConnectionTime), _
                            xi_strUserName:=UserName, _
                            xi_strNetName:=NetName
   
   m_colConnectEnum.Add p_objConnectionEnum

   Set p_objConnectionEnum = Nothing

End Sub

' *******************************************************
' Routine Name : (PUBLIC in CLASS) Property Get Item
' Written By   : L.J. Johnson
' Programmer   : L.J. Johnson [Slightly Tilted Software]
' Date Writen  : 04/26/1999 -- 12:32:21
' Inputs       : vntIndexKey:Variant -
' Outputs      : clsConnectionEnum --
' Description  : Get a single item (object) with the
'              :     passed index value.
' *******************************************************
Public Property Get Item(IndexKey As Variant) As clsConnectionEnum
Attribute Item.VB_UserMemId = 0
   Set Item = m_colConnectEnum(IndexKey)
End Property

' *******************************************************
' Routine Name : (PUBLIC in CLASS) Property Get Count
' Written By   : L.J. Johnson
' Programmer   : L.J. Johnson [Slightly Tilted Software]
' Date Writen  : 04/26/1999 -- 12:32:19
' Inputs       : N/A
' Outputs      : Long -- Count of items
' Description  : Get a count of the number of items (objects)
'              :     in the collection.
' *******************************************************
Public Property Get Count() As Long
   Count = m_colConnectEnum.Count
End Property

' *******************************************************
' Routine Name : (PUBLIC in CLASS) Property Get NewEnum
' Written By   : L.J. Johnson
' Programmer   : L.J. Johnson [Slightly Tilted Software]
' Date Writen  : 04/26/1999 -- 12:32:15
' Inputs       : N/A
' Outputs      : IUnknown --
' Description  : Used to expose the For...Next syntax to
'              :     the calling program
' *******************************************************
Public Property Get NewEnum() As IUnknown
Attribute NewEnum.VB_UserMemId = -4
Attribute NewEnum.VB_MemberFlags = "40"
   Set NewEnum = m_colConnectEnum.[_NewEnum]
End Property

' *******************************************************
' Routine Name : (PRIVATE in CLASS) Sub Class_Initialize
' Written By   : L.J. Johnson
' Programmer   : L.J. Johnson [Slightly Tilted Software]
' Date Writen  : 04/26/1999 -- 12:32:37
' Inputs       : N/A
' Outputs      : N/A
' Description  : Initialize the new collection
' *******************************************************
Private Sub Class_Initialize()
   Set m_colConnectEnum = New Collection
End Sub

' *******************************************************
' Routine Name : (PRIVATE in CLASS) Sub Class_Terminate
' Written By   : L.J. Johnson
' Programmer   : L.J. Johnson [Slightly Tilted Software]
' Date Writen  : 04/26/1999 -- 12:38:16
' Inputs       : N/A
' Outputs      : N/A
' Description  : Clean-up the collection
' *******************************************************
Private Sub Class_Terminate()
   Set m_colConnectEnum = Nothing
End Sub

' *******************************************************
' Routine Name : (PUBLIC in CLASS) Sub Init
' Written By   : L.J. Johnson
' Programmer   : L.J. Johnson [Slightly Tilted Software]
' Date Writen  : 04/26/1999 -- 12:32:32
' Inputs       : ByVal Qualifier:String   -
'              : ByVal ServerName:String  -
' Outputs      : N/A
' Description  : For this collection class, you **MUST**
'              :     call the Init() method before using
'              :     any of the properties since you must
'              :     fill-in the Qualifier string
' *******************************************************
Public Sub Init(ByVal Qualifier As String, _
                ByVal ServerName As String)
   
   m_strServerName = ServerName
   m_strQualifier = Qualifier
   
   ConnectionEnum

End Sub

' *******************************************************
' Routine Name : (PRIVATE in CLASS) Sub ConnectionEnum
' Written By   : L.J. Johnson
' Programmer   : L.J. Johnson [Slightly Tilted Software]
' Date Writen  : 04/26/1999 -- 12:32:30
' Inputs       : N/A
' Outputs      : N/A
' Description  : Called by the Init() method -- make the
'              :     appropriate API call(s) and fill in
'              :     the collection via the Add() function
' *******************************************************
Private Sub ConnectionEnum()
   Dim p_lngRtn                        As Long
   Dim p_abytServerName()              As Byte
   Dim p_abytQualifier()               As Byte
   Dim p_lngPtrBuffer                  As Long
   Dim p_lngEntriesRead                As Long
   Dim p_lngTotalEntries               As Long
   Dim p_lngResumeHwnd                 As Long
   Dim p_lngLoop                       As Long
   Dim p_lngConnectionID               As Long
   Dim p_enmConnectionType             As enumShareType
   Dim p_lngNumOpens                   As Long
   Dim p_lngNumUsers                   As Long
   Dim p_lngConnTime                   As Long
   Dim p_strUserName                   As String
   Dim p_strNetName                    As String
   Dim p_atypConnInfo()                As Connection_Info_1
   
   ' ------------------------------------------
   ' Initialize the variable(s)
   ' ------------------------------------------
   p_abytServerName = m_strServerName & Chr$(0)
   p_abytQualifier = m_strQualifier & Chr$(0)
   
   ' ------------------------------------------
   ' Make appropriate API call and check for error
   ' ------------------------------------------
   p_lngRtn = NetConnectionEnum(ServerName:=p_abytServerName(0), _
                                Qualifier:=p_abytQualifier(0), _
                                Level:=1, _
                                Buffer:=p_lngPtrBuffer, _
                                PreMaxLen:=4096&, _
                                EntriesRead:=p_lngEntriesRead, _
                                TotalEntries:=p_lngTotalEntries, _
                                Resume_Handle:=p_lngResumeHwnd)
                           
   If p_lngRtn <> NERR_Success Then
      MsgBox "Had an error with NetConnectionEnum, " & CStr(p_lngRtn) & _
             " -- " & ReturnApiErrString(p_lngRtn), _
             Buttons:=vbInformation, _
             Title:=g_constMsgTitle
      Exit Sub
   End If
   
   ' ------------------------------------------
   ' Exit if no entries found
   ' ------------------------------------------
   If p_lngEntriesRead < 1 Then
      Exit Sub
   End If
   
   ' ------------------------------------------
   ' Redim the type array to hold this info
   ' ------------------------------------------
   ReDim p_atypConnInfo(0 To p_lngEntriesRead - 1)

   ' ------------------------------------------
   ' Copy the pointer to the buffer into the
   '     type array
   ' ------------------------------------------
   CopyMem p_atypConnInfo(0), _
           ByVal p_lngPtrBuffer, _
           Len(p_atypConnInfo(0)) * p_lngEntriesRead

   ' ------------------------------------------
   ' Fill-in the info needed to call the
   '     Add() method
   ' ------------------------------------------
   For p_lngLoop = 0 To p_lngEntriesRead - 1
      p_lngConnectionID = p_atypConnInfo(p_lngLoop).coni1_id
      p_enmConnectionType = p_atypConnInfo(p_lngLoop).coni1_type
      p_lngNumOpens = p_atypConnInfo(p_lngLoop).coni1_num_opens
      p_lngNumUsers = p_atypConnInfo(p_lngLoop).coni1_num_users
      p_lngConnTime = p_atypConnInfo(p_lngLoop).coni1_time
      p_strUserName = PointerToUnicodeStr(p_atypConnInfo(p_lngLoop).coni1_username)
      p_strNetName = PointerToUnicodeStr(p_atypConnInfo(p_lngLoop).coni1_netname)
      
      ' ---------------------------------------
      ' If not a user (remote connection), then
      '     give the net name
      ' ---------------------------------------
      If p_strUserName = "" Then
         p_strUserName = p_strNetName
      End If
      
      Add ConnectionType:=p_enmConnectionType, _
          ConnectionID:=p_lngConnectionID, _
          NumOpens:=p_lngNumOpens, _
          NumUsers:=p_lngNumUsers, _
          ConnectionTime:=p_lngConnTime, _
          UserName:=p_strUserName, _
          NetName:=p_strNetName
   Next p_lngLoop
   
   ' ------------------------------------------
   ' Clean-up the buffer
   ' ------------------------------------------
   If p_lngPtrBuffer <> 0 Then
      NetApiBufferFree p_lngPtrBuffer
   End If
   
End Sub

