VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
END
Attribute VB_Name = "colSessionEnum"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = True
Attribute VB_PredeclaredId = False
Attribute VB_Exposed = True
Attribute VB_Ext_KEY = "SavedWithClassBuilder" ,"Yes"
Attribute VB_Ext_KEY = "Collection" ,"clsSessionEnum"
Attribute VB_Ext_KEY = "Member0" ,"clsSessionEnum"
Attribute VB_Ext_KEY = "Top_Level" ,"Yes"
' ------------------------------------------------------
' colSessionEnum.CLS
' Copyright (c) Slightly Tilted Software 1999
' By: L.J. Johnson       Date: 04-26-1999
' Comments: Collection class to manage collection of
'           Session enumeration objects
' ------------------------------------------------------
Option Explicit
Option Base 1
Option Compare Text
DefLng A-Z

' --------------------------------------------
' Private variable to hold public property value
' --------------------------------------------
Private m_strServerName                As String

' --------------------------------------------
' Local variable to hold collection
' --------------------------------------------
Private m_colSessionEnum As Collection

' *******************************************************
' Routine Name : (PRIVATE in CLASS) Sub Add
' Written By   : L.J. Johnson
' Programmer   : L.J. Johnson [Slightly Tilted Software]
' Date Writen  : 04/26/1999 -- 12:28:25
' Inputs       : ByVal ComputerName:String -
'              : ByVal UserName:String     -
'              : ByVal Transport:String    -
'              : ByVal NumOpens:Long       -
'              : ByVal ActiveTime:Long     -
'              : ByVal IdleTime:Long       -
'              : ByVal UserFlags:enumUserFlags -
' Outputs      : N/A
' Description  : Don't have a public Add() method -- the
'              :     API call in SessionEnum() -- which
'              :     is called by the Class_Initialize method
'              :     --  will populate the info via repeated
'              :     calls to the Add() method
' *******************************************************
Private Sub Add(ByVal ComputerName As String, _
                ByVal UserName As String, _
                ByVal Transport As String, _
                ByVal NumOpens As Long, _
                ByVal ActiveTime As Long, _
                ByVal IdleTime As Long, _
                ByVal UserFlags As enumUserFlags)
   Dim p_objSessionEnum                As clsSessionEnum
   
   Set p_objSessionEnum = New clsSessionEnum
   p_objSessionEnum.Init xi_strComputerName:=ComputerName, _
                         xi_strUserName:=UserName, _
                         xi_strTransport:=Transport, _
                         xi_lngNumOpens:=NumOpens, _
                         xi_lngActiveTime:=ActiveTime, _
                         xi_strActiveTimeFormatted:=ConvertSeconds(ActiveTime), _
                         xi_lngIdleTime:=IdleTime, _
                         xi_strIdleTimeFormatted:=ConvertSeconds(IdleTime), _
                         xi_enmUserFlags:=UserFlags

   m_colSessionEnum.Add p_objSessionEnum

   Set p_objSessionEnum = Nothing

End Sub

' *******************************************************
' Routine Name : (PUBLIC in CLASS) Property Get Item
' Written By   : L.J. Johnson
' Programmer   : L.J. Johnson [Slightly Tilted Software]
' Date Writen  : 04/26/1999 -- 12:32:21
' Inputs       : vntIndexKey:Variant -
' Outputs      : clsConnectionEnum --
' Description  : Get a single item (object) with the
'              :     passed index value.
' *******************************************************
Public Property Get Item(IndexKey As Variant) As clsSessionEnum
Attribute Item.VB_UserMemId = 0
   Set Item = m_colSessionEnum(IndexKey)
End Property

' *******************************************************
' Routine Name : (PUBLIC in CLASS) Property Get Count
' Written By   : L.J. Johnson
' Programmer   : L.J. Johnson [Slightly Tilted Software]
' Date Writen  : 04/26/1999 -- 12:32:19
' Inputs       : N/A
' Outputs      : Long -- Count of items
' Description  : Get a count of the number of items (objects)
'              :     in the collection.
' *******************************************************
Public Property Get Count() As Long
   Count = m_colSessionEnum.Count
End Property

' *******************************************************
' Routine Name : (PUBLIC in CLASS) Property Get NewEnum
' Written By   : L.J. Johnson
' Programmer   : L.J. Johnson [Slightly Tilted Software]
' Date Writen  : 04/26/1999 -- 12:32:15
' Inputs       : N/A
' Outputs      : IUnknown --
' Description  : Used to expose the For...Next syntax to
'              :     the calling program
' *******************************************************
Public Property Get NewEnum() As IUnknown
Attribute NewEnum.VB_UserMemId = -4
Attribute NewEnum.VB_MemberFlags = "40"
   Set NewEnum = m_colSessionEnum.[_NewEnum]
End Property

' *******************************************************
' Routine Name : (PUBLIC in CLASS) Sub Init
' Written By   : L.J. Johnson
' Programmer   : L.J. Johnson [Slightly Tilted Software]
' Date Writen  : 05/03/1999 -- 09:23:26
' Inputs       : ByVal ServerName:String -
' Outputs      : N/A
' Description  :
'              :
'              :
' Called By    : UI
' *******************************************************
Public Sub Init(ByVal ServerName As String)
   
   m_strServerName = ServerName
   SessionEnum

End Sub

' *******************************************************
' Routine Name : (PRIVATE in CLASS) Sub Class_Initialize
' Written By   : L.J. Johnson
' Programmer   : L.J. Johnson [Slightly Tilted Software]
' Date Writen  : 04/26/1999 -- 12:32:37
' Inputs       : N/A
' Outputs      : N/A
' Description  : Initialize the new collection and setup
'              :     the public properties via a call to
'              :     SessionEnum
' *******************************************************
Private Sub Class_Initialize()
   Set m_colSessionEnum = New Collection
End Sub

' *******************************************************
' Routine Name : (PRIVATE in CLASS) Sub Class_Terminate
' Written By   : L.J. Johnson
' Programmer   : L.J. Johnson [Slightly Tilted Software]
' Date Writen  : 04/26/1999 -- 12:38:16
' Inputs       : N/A
' Outputs      : N/A
' Description  : Clean-up the collection
' *******************************************************
Private Sub Class_Terminate()
   Set m_colSessionEnum = Nothing
End Sub

' *******************************************************
' Routine Name : (PRIVATE in CLASS) Sub SessionEnum
' Written By   : L.J. Johnson
' Programmer   : L.J. Johnson [Slightly Tilted Software]
' Date Writen  : 04/26/1999 -- 12:43:07
' Inputs       : N/A
' Outputs      : N/A
' Description  : Called by the Class_Initialize() method --
'              :     make the appropriate API call(s) and fill
'              :     in the collection via the Add() function
' *******************************************************
Private Sub SessionEnum()
   Dim p_lngRtn                        As Long
   Dim p_abytServerName()              As Byte
   Dim p_abytUncClientName()           As Byte
   Dim p_abytUserName()                As Byte
   Dim p_lngPtrBuffer                  As Long
   Dim p_lngEntriesRead                As Long
   Dim p_lngTotalEntries               As Long
   Dim p_lngResumeHwnd                 As Long
   Dim p_lngLoop                       As Long
   Dim p_strComputerName               As String
   Dim p_strUserName                   As String
   Dim p_strTransport                  As String
   Dim p_lngNumOpens                   As Long
   Dim p_lngActiveTime                 As Long
   Dim p_lngIdleTime                   As Long
   Dim p_enmUserFlags                  As enumUserFlags
   Dim p_atypSessionInfo()             As Session_Info_502
   
   ' ------------------------------------------
   ' Initialize the variable(s)
   ' ------------------------------------------
   p_abytServerName = m_strServerName & Chr$(0)
   p_abytUncClientName = Chr$(0)
   p_abytUserName = Chr$(0)

   ' ------------------------------------------
   ' Make appropriate API call and check for error
   ' ------------------------------------------
   p_lngRtn = NetSessionEnum(ServerName:=p_abytServerName(0), _
                             UncClientName:=p_abytUncClientName(0), _
                             UserName:=p_abytUserName(0), _
                             Level:=502, _
                             Buffer:=p_lngPtrBuffer, _
                             PreMaxLen:=4096, _
                             EntriesRead:=p_lngEntriesRead, _
                             TotalEntries:=p_lngTotalEntries, _
                             Resume_Handle:=p_lngResumeHwnd)
   If p_lngRtn <> 0 Then
      MsgBox "Had an error with NetSessionEnum, " & CStr(p_lngRtn) & _
             " -- " & ReturnApiErrString(p_lngRtn), _
             Buttons:=vbInformation, _
             Title:=g_constMsgTitle
      Exit Sub
   End If

   ' ------------------------------------------
   ' Exit if no entries found
   ' ------------------------------------------
   If p_lngEntriesRead < 1 Then
      Exit Sub
   End If

   ' ------------------------------------------
   ' Redim the type array to hold this info
   ' ------------------------------------------
   ReDim p_atypSessionInfo(0 To p_lngEntriesRead - 1)

   ' ------------------------------------------
   ' Copy the pointer to the buffer into the
   '     type array
   ' ------------------------------------------
   CopyMem p_atypSessionInfo(0), _
           ByVal p_lngPtrBuffer, _
           Len(p_atypSessionInfo(0)) * p_lngEntriesRead

   ' ------------------------------------------
   ' Fill-in the info needed to call the
   '     Add() method
   ' ------------------------------------------
   For p_lngLoop = 0 To p_lngEntriesRead - 1
      p_strComputerName = PointerToUnicodeStr(p_atypSessionInfo(p_lngLoop).sesi502_cname)
      p_strUserName = PointerToUnicodeStr(p_atypSessionInfo(p_lngLoop).sesi502_username)
      p_strTransport = PointerToUnicodeStr(p_atypSessionInfo(p_lngLoop).sesi502_transport)
      p_lngNumOpens = p_atypSessionInfo(p_lngLoop).sesi502_num_opens
      p_lngActiveTime = p_atypSessionInfo(p_lngLoop).sesi502_time
      p_lngIdleTime = p_atypSessionInfo(p_lngLoop).sesi502_idle_time
      p_enmUserFlags = p_atypSessionInfo(p_lngLoop).sesi502_user_flags
      
      Add ComputerName:=p_strComputerName, _
          UserName:=p_strUserName, _
          Transport:=p_strTransport, _
          NumOpens:=p_lngNumOpens, _
          ActiveTime:=p_lngActiveTime, _
          IdleTime:=p_lngIdleTime, _
          UserFlags:=p_enmUserFlags
   Next p_lngLoop
  
   ' ------------------------------------------
   ' Clean-up the buffer
   ' ------------------------------------------
   If p_lngPtrBuffer <> 0 Then
      NetApiBufferFree p_lngPtrBuffer
   End If
   
End Sub

' *******************************************************
' Routine Name : (PUBLIC in CLASS) Sub DeleteItem
' Written By   : L.J. Johnson
' Programmer   : L.J. Johnson [Slightly Tilted Software]
' Date Writen  : 04/26/1999 -- 12:42:33
' Inputs       : ByVal UncClientName:String - Machine's name
'              : ByVal UserName:String      - User's name
' Outputs      : N/A
' Description  : Passed the name of the user and the machine
'              :     this session is on, delete this
'              :     session.
' *******************************************************
Public Sub DeleteItem(ByVal UncClientName As String, _
                      ByVal UserName As String)
   Dim p_lngRtn                        As Long
   Dim p_abytServerName()              As Byte
   Dim p_abytUncClientName()           As Byte
   Dim p_abytUserName()                As Byte
   
   ' ------------------------------------------
   ' Initialize the variable(s)
   ' ------------------------------------------
   p_abytServerName = m_strServerName & Chr$(0)
   p_abytUncClientName = "\\" & UncClientName & Chr$(0)
   p_abytUserName = UserName & Chr$(0)
   
   ' ------------------------------------------
   ' Make appropriate API call and check for error
   ' ------------------------------------------
   p_lngRtn = NetSessionDel(ServerName:=p_abytServerName(0), _
                            UncClientName:=p_abytUncClientName(0), _
                            UserName:=p_abytUserName(0))
   If p_lngRtn <> NERR_Success Then
      MsgBox "Had an error with NetSessionDel, " & CStr(p_lngRtn) & _
             " -- " & ReturnApiErrString(p_lngRtn), _
             Buttons:=vbInformation, _
             Title:=g_constMsgTitle
   End If
   
End Sub
